@@ -4,7 +4,7 @@ Main interface for appsync service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_appsync import (
         AppSyncClient,
         Client,
@@ -17,10 +17,8 @@ Usage::
         ListTypesPaginator,
     )
 
-    session = boto3.Session()
-
-    client: AppSyncClient = boto3.client("appsync")
-    session_client: AppSyncClient = session.client("appsync")
+    session = Session()
+    client: AppSyncClient = session.client("appsync")
 
     list_api_keys_paginator: ListApiKeysPaginator = client.get_paginator("list_api_keys")
     list_data_sources_paginator: ListDataSourcesPaginator = client.get_paginator("list_data_sources")
