@@ -51,6 +51,7 @@ from .type_defs import (
     CreateTypeResponseTypeDef,
     DynamodbDataSourceConfigTypeDef,
     ElasticsearchDataSourceConfigTypeDef,
+    EvaluateMappingTemplateResponseTypeDef,
     GetApiAssociationResponseTypeDef,
     GetApiCacheResponseTypeDef,
     GetDataSourceResponseTypeDef,
@@ -367,6 +368,16 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#disassociate_api)
         """
 
+    def evaluate_mapping_template(
+        self, *, template: str, context: str
+    ) -> EvaluateMappingTemplateResponseTypeDef:
+        """
+        Evaluates a given template and returns the response.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.evaluate_mapping_template)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#evaluate_mapping_template)
+        """
+
     def flush_api_cache(self, *, apiId: str) -> Dict[str, Any]:
         """
         Flushes an `ApiCache` object.
